unit uEntities;

interface

uses
  SysUtils,
  Generics.Collections,
  Aurelius.Mapping.Attributes,
  Aurelius.Types.Blob,
  Aurelius.Types.DynamicProperties,
  Aurelius.Types.Nullable,
  Aurelius.Types.Proxy,

  Aurelius.Validation.Attributes;

type
  TTest = class;

  {$RTTI EXPLICIT METHODS([vcPrivate..vcPublished])}
  [Entity]
  [Table('Test')]
  [Id('FID', TIdGenerator.IdentityOrSequence)]
  TTest = class
  private
    [Column('ID', [TColumnProp.Required, TColumnProp.NoInsert, TColumnProp.NoUpdate])]
    FID: Integer;

    [Column('Year', [])]
    FYear: Nullable<Integer>;

    [Column('Description', [], 50)]
    [MinLength(4)]
    FDescription: Nullable<string>;
  public
    [OnValidate]
    function CheckYear: IValidationResult;
    property Id: Integer read FID write FID;
    property Year: Nullable<Integer> read FYear write FYear;
    property Description: Nullable<string> read FDescription write FDescription;
  end;

implementation

uses Aurelius.Validation;

{ TTest }

function TTest.CheckYear: IValidationResult;
begin
  result := TValidationResult.Create;
  if Year.IsNull then
    Exit;

  if Year <> 2024 then
    result.Errors.Add(TValidationError.Create('Year must be 2024!'));
end;

initialization

RegisterEntity(TTest);

end.
